@@ -1,12 +1,13 @@
 from pydantic import BaseModel
 import requests
 from requests.adapters import HTTPAdapter
+from .. import decorator
 
 class HttpRequest(BaseModel):
     retry_times: int = 5 # http 重试次数
     timeout:int = 30    # 超时时间
 
-    @singleton
+    @decorator.singleton
     def requests(self) -> requests.Session:
         s = requests.Session()
         s.mount('http://', HTTPAdapter(max_retries=self.retry_times))
